
package de.codedo.conflicteditor.gui;

import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.HeadlessException;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.table.TableModel;

public class ConflictEditorFrame extends JFrame
{
    private JTextField _databaseUrlTextField;
    private JButton _findConflictsButton;
    private JList _conflictsList;
    private JTable _differencesTable;

    public ConflictEditorFrame() throws HeadlessException
    {
        super();
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLayout(new GridBagLayout());
        buildGui();
    }

    private void buildGui()
    {
        buildDatabaseUrlPanel();
        buildConflictsListAndDifferencesTable();
    }

    private void buildDatabaseUrlPanel()
    {
        JLabel label = new JLabel("Database URL:");
        _databaseUrlTextField = new JTextField(40);
        _findConflictsButton = new JButton("Find Conflicts");

        JPanel databaseUrlPanel = new JPanel();
        FlowLayout layout = new FlowLayout(FlowLayout.LEFT);
        databaseUrlPanel.setLayout(layout);
        databaseUrlPanel.add(label);
        databaseUrlPanel.add(_databaseUrlTextField);
        databaseUrlPanel.add(_findConflictsButton);

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.gridx = 0;
        constraints.gridy = 0;
        constraints.weightx = 0.5;
        constraints.weighty = 0.1;
        constraints.anchor = GridBagConstraints.LINE_START;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        getContentPane().add(databaseUrlPanel, constraints);
    }

    private void buildConflictsListAndDifferencesTable()
    {
        buildConflictsList();
        buildDifferencesTable();

        JScrollPane conflictsScrollPane = new JScrollPane(_conflictsList);
        JScrollPane differencesScrollPane = new JScrollPane(_differencesTable);

        JSplitPane splitPane = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
        splitPane.add(conflictsScrollPane);
        splitPane.add(differencesScrollPane);

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.gridx = 0;
        constraints.gridy = 1;
        constraints.weightx = 0.5;
        constraints.weighty = 0.9;
        constraints.fill = GridBagConstraints.BOTH;
        getContentPane().add(splitPane, constraints);
    }

    private void buildConflictsList()
    {
        _conflictsList = new JList();
    }

    private void buildDifferencesTable()
    {
        _differencesTable = new JTable();
        _differencesTable.setDefaultRenderer(Object.class, new SpecialCharactersTableCellRenderer());

        TableModel model = new DifferenceTableModel();
        _differencesTable.setModel(model);
    }

    public JTextField getDatabaseUrlTextField()
    {
        return _databaseUrlTextField;
    }

    public JButton getFindConflictsButton()
    {
        return _findConflictsButton;
    }

    public JList getConflictsList()
    {
        return _conflictsList;
    }

    public JTable getDifferencesTable()
    {
        return _differencesTable;
    }
}
